function [gradSAns_x,gradSAns_y, gradCTns_x,gradCTns_y] = gsw_ns2d_SA_CT_xy_gradients(SAns,CTns,e1t,e2t,settings)

%           Find the gradient of a variable in x and y-direction.
%
% Usage:    [grad_x,grad_y] = grad_surf(var_surf,e1t,e2t,keyword,wrap)
%
%
% Input:    var                   variable 
%           e1t                   zonal scale-factor at var_surf points 
%           e2t                   meridional scale-factor at var_surf 
%                                 points
% %           wrap                  'none'
% %                                 'long'
%
% Output:   grad_x                gradient in zonal direction 
%           grad_y                gradient in meridional direction 
%
% Units:    scale factors         m         
%
%   _________________________________________________________________
%   This is part of the analyze_surface toolbox, (C) 2009 A. Klocker
%   type 'help analyze_surface' for more information 
%   type 'analyze_surface_license' for license details
%   type 'analyze_surface_version' for version details
%

if ~(nargin == 5)
    error('gsw_ns2d_SA_CT_xy_gradients: requires 5 input arguments')
end

[yi,xi] = size(SAns);

rec_e1t = 1./e1t;
rec_e2t = 1./e2t;

% calculate in longitude direction
gradSAns_x(1:yi,1:xi-1) = (SAns(1:yi,2:xi) - SAns(1:yi,1:xi-1)) .* rec_e1t(1:yi,1:xi-1);
gradCTns_x(1:yi,1:xi-1) = (CTns(1:yi,2:xi) - CTns(1:yi,1:xi-1)) .* rec_e1t(1:yi,1:xi-1);

switch settings.wrap
    
    case {'none'}
        
        gradSAns_x(1:yi,xi) = nan;
        gradCTns_x(1:yi,xi) = nan;
        
    case {'long'}
        
        gradSAns_x(1:yi,xi) = (SAns(1:yi,1) - SAns(1:yi,xi)) .* rec_e1t(1:yi,1);
        gradCTns_x(1:yi,xi) = (CTns(1:yi,1) - CTns(1:yi,xi)) .* rec_e1t(1:yi,1);
end

% calculate in latitude direction
gradSAns_y(1:yi-1,1:xi) = (SAns(2:yi,1:xi) - SAns(1:yi-1,1:xi)) .* rec_e2t(1:yi-1,1:xi);
gradSAns_y(yi,1:xi) = nan;
gradCTns_y(1:yi-1,1:xi) = (CTns(2:yi,1:xi) - CTns(1:yi-1,1:xi)) .* rec_e2t(1:yi-1,1:xi);
gradCTns_y(yi,1:xi) = nan;

end