function [meanSAns_x,meanSAns_y, meanCTns_x,meanCTns_y] = gsw_ns2d_SA_CT_xy_mean(SAns,CTns,settings)

%           Find the mean of a variables in x and y-direction.
%
% Usage:    [grad_x,grad_y] = grad_surf(var_surf,e1t,e2t,keyword,wrap)
%
%
% Input:    var                   variable 
%           e1t                   zonal scale-factor at var_surf points 
%           e2t                   meridional scale-factor at var_surf 
%                                 points
% %           wrap                  'none'
% %                                 'long'
%
% Output:   grad_x                gradient in zonal direction 
%           grad_y                gradient in meridional direction 
%
% Units:    scale factors         m         
%
%   _________________________________________________________________
%   This is part of the analyze_surface toolbox, (C) 2009 A. Klocker
%   type 'help analyze_surface' for more information 
%   type 'analyze_surface_license' for license details
%   type 'analyze_surface_version' for version details
%

if ~(nargin == 5)
    error('gsw_ns2d_SA_CT_xy_mean: requires 5 input arguments')
end

[yi,xi] = size(SAns);

% calculate in longitude direction
meanSAns_x(1:yi,1:xi-1) = 0.5*(SAns(1:yi,2:xi) + SAns(1:yi,1:xi-1));
meanCTns_x(1:yi,1:xi-1) = 0.5*(CTns(1:yi,2:xi) - CTns(1:yi,1:xi-1));

switch settings.wrap
    
    case {'none'}
        
        meanSAns_x(1:yi,xi) = nan;
        meanCTns_x(1:yi,xi) = nan;
        
    case {'long'}
        
        meanSAns_x(1:yi,xi) = 0.5*(SAns(1:yi,1) - SAns(1:yi,xi));
        meanCTns_x(1:yi,xi) = (CTns(1:yi,1) - CTns(1:yi,xi));
end

% calculate in latitude direction
meanSAns_y(1:yi-1,1:xi) = 0.5*(SAns(2:yi,1:xi) - SAns(1:yi-1,1:xi));
meanSAns_y(yi,1:xi) = nan;
meanCTns_y(1:yi-1,1:xi) = 0.5*(CTns(2:yi,1:xi) - CTns(1:yi-1,1:xi));
meanCTns_y(yi,1:xi) = nan;

end